@@ -19,13 +19,8 @@
 #    at /usr/share/common-licenses/GPL
 ####################################################################################
 
-files=$( cat desktop-guide/libs/shipped-docs )
-for file in $files
-do
-	filepath="desktop-guide/C/$file.xml"
-	filepaths="$filepaths $filepath"
+for x in `cat libs/shipped-docs`; do
+	echo ${x}
+	xml2po -e -o ${x}/po/${x}.pot ${x}/C/*.xml
 done
 
-xml2po -e -o desktop-guide/po/desktop-guide.pot $filepaths
-
-
